@@ -24,6 +24,7 @@ import tenacity
 from tooz import coordination
 
 from networking_generic_switch.devices import netmiko_devices
+from networking_generic_switch.devices import utils
 from networking_generic_switch import exceptions as exc
 
 
@@ -62,7 +63,7 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
                 'NetmikoSwitch.check_output')
     def test_add_network_with_trunk_ports(self, m_check, m_sctd):
-        switch = self._make_switch_device({'ngs_trunk_ports': 'port1,port2'})
+        switch = self._make_switch_device({'ngs_trunk_ports': 'port1, port2'})
         switch.add_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
         m_sctd.assert_called_with([])
         m_check.assert_called_once_with('fake output', 'add network')
@@ -94,7 +95,7 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
                 'NetmikoSwitch.check_output')
     def test_del_network_with_trunk_ports(self, m_check, m_sctd):
-        switch = self._make_switch_device({'ngs_trunk_ports': 'port1,port2'})
+        switch = self._make_switch_device({'ngs_trunk_ports': 'port1, port2'})
         switch.del_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
         m_sctd.assert_called_with([])
         m_check.assert_called_once_with('fake output', 'delete network')
@@ -342,17 +343,18 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
         connect_mock.send_command.assert_has_calls([mock.call('save'),
                                                     mock.call('y')])
 
+    @mock.patch.object(utils, 'get_hostname', autospec=True)
     @mock.patch.object(netmiko_devices.ngs_lock, 'PoolLock', autospec=True)
     @mock.patch.object(netmiko_devices.netmiko, 'ConnectHandler')
     @mock.patch.object(coordination, 'get_coordinator', autospec=True)
     def test_switch_send_commands_with_coordinator(self, get_coord_mock,
-                                                   nm_mock, lock_mock):
+                                                   nm_mock, lock_mock,
+                                                   mock_hostname):
         self.cfg.config(acquire_timeout=120, backend_url='mysql://localhost',
                         group='ngs_coordination')
-        self.cfg.config(host='viking')
         coord = mock.Mock()
         get_coord_mock.return_value = coord
-
+        mock_hostname.return_value = 'viking'
         switch = self._make_switch_device(
             extra_cfg={'ngs_max_connections': 2})
         self.assertEqual(coord, switch.locker)
@@ -370,6 +372,7 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
                                           timeout=120)
         lock_mock.return_value.__exit__.assert_called_once()
         lock_mock.return_value.__enter__.assert_called_once()
+        mock_hostname.assert_called_once()
 
     def test_check_output(self):
         self.switch.check_output('fake output', 'fake op')
